@@ -2,6 +2,7 @@
 
 import os
 import filecmp
+import shlex
 from pathlib import Path
 import pytest
 
@@ -20,12 +21,12 @@ from class_generator.class_generator import TESTS_MANIFESTS_DIR, class_generator
         "ImageContentSourcePolicy",
         "Machine",
         "NMState",
-        "OAuth",
         "Pod",
         "Secret",
         "ServiceMeshMember",
-        "ServingRuntime",
+        "OAuth",
         "Pipeline",
+        "ServingRuntime",
     ),
 )
 def test_parse_explain(tmpdir_factory, kind):
@@ -35,4 +36,8 @@ def test_parse_explain(tmpdir_factory, kind):
         output_dir=output_dir,
     )
     for output_file in output_files:
-        assert filecmp.cmp(output_file, f"{os.path.join(TESTS_MANIFESTS_DIR, kind, Path(output_file).parts[-1])}")
+        expected_file = f"{os.path.join(TESTS_MANIFESTS_DIR, kind, Path(output_file).parts[-1])}"
+        files_match = filecmp.cmp(output_file, expected_file)
+        if not files_match:
+            os.system(f"diff {shlex.quote(str(output_file))} {shlex.quote(str(expected_file))}")
+            pytest.fail(f"Generated file: {output_file} does not match expected file: {expected_file}")
