@@ -65,7 +65,7 @@ class PersistentVolumeClaim(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res.update({
                 "spec": {
                     "volumeMode": self.volume_mode,
