@@ -41,7 +41,7 @@ class SriovNetwork(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res["spec"] = {
                 "ipam": self.ipam or "{}\n",
                 "networkNamespace": self.network_namespace,
